# abfallnavi
Termine für Leerung des Abfalls nach Abfallart (Papier, Restmüll, ...). Beispielswerte sind für das Rathaus Nürnberg (Hauptmarkt 18, Nürnberg).

# Kommunen / Regionen

Das System ist in diverse Regionen unterteilt. Zu einer `Region` gehören ein oder mehrere Kommunen.

* `aachen`: Aachen
* `zew2`: AWA Entsorgungs GmbH
* `aw-bgl2`: Bergisch Gladbach
* `bav`: Bergischer Abfallwirtschaftverbund
* `din`: Dinslaken
* `dorsten`: Dorsten
* `gt2`: Gütersloh
* `hlv`: Halver
* `coe`: Kreis Coesfeld
* `krhs`: Kreis Heinsberg
* `pi`: Kreis Pinneberg
* `krwaf`: Kreis Warendorf
* `lindlar`: Lindlar
* `stl`: Lüdenscheid
* `nds`: Norderstedt
* `nuernberg`: Nürnberg
* `roe`: Roetgen
* `solingen`: Solingen
* `wml2`: EGW Westmünsterland

# Benutzung

Für die Abfrage von Terminen ist eine Reihe von IDs (von Orten, Straßen und/oder Hausnummern) in Erfahrung zu bringen. Vorsicht:IDs können sich mit der Zeit ändern

1. Orte aus System holen
2. Mit Ort die Straßen abfragen
3. Mit Straße die Hausnummern abfragen
4. Mit Haunummer die möglichen Fraktionen (Müllsorten) abfragen
5. Mit Hausnummer und Fraktionen alle Termine abrufen

Manchmal wird nicht nach Hausnummer unterschieden


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 0.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

```sh
pip install deutschland[abfallnavi]
```

### poetry install

```sh
poetry add deutschland -E abfallnavi
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

## Usage

Import the package:
```python
from deutschland import abfallnavi
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
from deutschland import abfallnavi
from pprint import pprint
from deutschland.abfallnavi.api import abholpunkte_api
from deutschland.abfallnavi.model.ort import Ort
from deutschland.abfallnavi.model.ort2 import Ort2
from deutschland.abfallnavi.model.strasse import Strasse
# Defining the host is optional and defaults to https://nuernberg-abfallapp.regioit.de/abfall-app-nuernberg/rest
# See configuration.py for a list of all supported configuration parameters.
configuration = abfallnavi.Configuration(
    host = "https://nuernberg-abfallapp.regioit.de/abfall-app-nuernberg/rest"
)



# Enter a context with an instance of the API client
with abfallnavi.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = abholpunkte_api.AbholpunkteApi(api_client)
    strassen_id = 1 # int | Id der Straße

    try:
        # Hausnummern in Straße
        api_response = api_instance.hausnummern_pro_strasse(strassen_id)
        pprint(api_response)
    except abfallnavi.ApiException as e:
        print("Exception when calling AbholpunkteApi->hausnummern_pro_strasse: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://nuernberg-abfallapp.regioit.de/abfall-app-nuernberg/rest*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AbholpunkteApi* | [**hausnummern_pro_strasse**](docs/AbholpunkteApi.md#hausnummern_pro_strasse) | **GET** /strassen/{strassenId} | Hausnummern in Straße
*AbholpunkteApi* | [**ort**](docs/AbholpunkteApi.md#ort) | **GET** /orte/{ortId} | Informationen zu Ort
*AbholpunkteApi* | [**orte**](docs/AbholpunkteApi.md#orte) | **GET** /orte | Orte im System
*AbholpunkteApi* | [**strassen_pro_ort**](docs/AbholpunkteApi.md#strassen_pro_ort) | **GET** /orte/{ortId}/strassen | Straßen im Ort
*FraktionenApi* | [**muellarten**](docs/FraktionenApi.md#muellarten) | **GET** /fraktionen | Müllarten im System
*FraktionenApi* | [**muellarten_pro_hausnummer**](docs/FraktionenApi.md#muellarten_pro_hausnummer) | **GET** /hausnummern/{hausnummernId}/fraktionen | Müllarten für Hausnummer
*FraktionenApi* | [**muellarten_pro_strasse**](docs/FraktionenApi.md#muellarten_pro_strasse) | **GET** /strassen/{strassenId}/fraktionen | Müllarten für Straßen
*TermineApi* | [**download_as_file**](docs/TermineApi.md#download_as_file) | **GET** /kalender-{region}/downloadfile.jsp | Datenexport als PDF oder ICS
*TermineApi* | [**termine_pro_haussnummer**](docs/TermineApi.md#termine_pro_haussnummer) | **GET** /hausnummern/{hausnummernId}/termine | Abholtermine für Hausnummer
*TermineApi* | [**termine_pro_strasse**](docs/TermineApi.md#termine_pro_strasse) | **GET** /strassen/{strassenId}/termine | Abholtermine für Straße


## Documentation For Models

 - [Abholung](docs/Abholung.md)
 - [Bezirk](docs/Bezirk.md)
 - [Fraktion](docs/Fraktion.md)
 - [Hausnummer](docs/Hausnummer.md)
 - [Ort](docs/Ort.md)
 - [Ort2](docs/Ort2.md)
 - [OrtInner](docs/OrtInner.md)
 - [Region](docs/Region.md)
 - [Strasse](docs/Strasse.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

kontakt@bund.dev


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in abfallnavi.apis and abfallnavi.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from deutschland.abfallnavi.api.default_api import DefaultApi`
- `from deutschland.abfallnavi.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
from deutschland import abfallnavi
from deutschland.abfallnavi.apis import *
from deutschland.abfallnavi.models import *
```

